>From c3f65139031fd0b5a441adf1a597e070b2f716c8 Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Wed, 9 Nov 2016 12:00:00 -0500
Subject: [PATCH 2/2] Add support for documentation built by XSL stylesheets

The class names and in some cases elements differ a bit between DSSSL
and XSL builds.
---
 media/css/docs.css | 59 +++++++++++++++++++++++++++++++++++++++++++++++++++++-
 1 file changed, 58 insertions(+), 1 deletion(-)

diff --git a/media/css/docs.css b/media/css/docs.css
index d19560f..10d6f48 100644
--- a/media/css/docs.css
+++ b/media/css/docs.css
@@ -1,11 +1,20 @@
 /* PostgreSQL.org Documentation Style */
 
+/*
+ * Documentation generated by XSL stylesheets has lower-case class
+ * names, older documentation generated by DSSSL stylesheets has
+ * upper-case class names, so we need to support both for a while.  In
+ * some cases, the elements and classes differ further between the two
+ * stylesheets.
+ */
+
 /* requires global.css, table.css and text.css to be loaded before this file! */
 body {
   font-size: 76%;
 }
 
-div.NAVHEADER table {
+.navheader table,
+.NAVHEADER table {
   margin-left: 0;
 }
 
@@ -178,10 +187,12 @@ h4 a:hover {
 
 /* Text Styles */
 
+div.sect2,
 div.SECT2 {
   margin-top: 4ex;
 }
 
+div.sect3,
 div.SECT3 {
   margin-top: 3ex;
   margin-left: 3ex;
@@ -226,6 +237,16 @@ p, ol, ul, li {
   font-size: 1em;
 }
 
+pre.literallayout,
+.screen,
+.synopsis,
+.programlisting,
+.refsynopsisdiv p,
+.caution,
+.warning,
+.note,
+.tip,
+table.table,
 pre.LITERALLAYOUT,
 .SCREEN,
 .SYNOPSIS,
@@ -243,6 +264,15 @@ table.CALSTABLE {
   box-shadow: 3px 3px 5px #DFDFDF;
 }
 
+pre.literallayout,
+.screen,
+.synopsis,
+.programlisting,
+.refsynopsisdiv p,
+.caution,
+.warning,
+.note,
+.tip,
 pre.LITERALLAYOUT,
 .SCREEN,
 .SYNOPSIS,
@@ -264,6 +294,11 @@ blockquote.TIP {
   border-radius: 8px;
 }
 
+pre.literallayout,
+pre.synopsis,
+pre.programlisting,
+.refsynopsisdiv p,
+.screen,
 pre.LITERALLAYOUT,
 pre.SYNOPSIS,
 pre.PROGRAMLISTING,
@@ -273,6 +308,8 @@ pre.PROGRAMLISTING,
   background-color: #F7F7F7;
 }
 
+.note,
+.tip,
 blockquote.NOTE,
 blockquote.TIP {
   border-color: #DBDBCC;
@@ -281,6 +318,10 @@ blockquote.TIP {
   width: 572px;
 }
 
+.note,
+.tip,
+.caution,
+.warning,
 blockquote.NOTE,
 blockquote.TIP,
 table.CAUTION,
@@ -288,11 +329,17 @@ table.WARNING {
   margin: 4ex auto;
 }
 
+.note p,
+.tip p,
 blockquote.NOTE p,
 blockquote.TIP p {
   margin: 0;
 }
 
+.note pre,
+.note code,
+.tip pre,
+.tip code,
 blockquote.NOTE pre,
 blockquote.NOTE code,
 blockquote.TIP pre,
@@ -311,6 +358,7 @@ blockquote.TIP code {
   font-weight: bold;
 }
 
+.replaceable,
 .REPLACEABLE {
   font-style: italic;
 }
@@ -321,6 +369,8 @@ table {
   margin-left: 2ex;
 }
 
+table.table td,
+table.table th,
 table.CALSTABLE td,
 table.CALSTABLE th,
 table.CAUTION td,
@@ -330,6 +380,7 @@ table.WARNING th {
   border-style: solid;
 }
 
+table.table,
 table.CALSTABLE,
 table.CAUTION,
 table.WARNING {
@@ -337,6 +388,7 @@ table.WARNING {
   border-collapse: collapse;
 }
 
+table.table,
 table.CALSTABLE
 {
   margin: 2ex 0 2ex 2ex;
@@ -344,15 +396,19 @@ table.CALSTABLE
   border: 2px solid #A7C6DF;
 }
 
+table.table tr:hover td,
 table.CALSTABLE tr:hover td
 {
   background-color: #EFEFEF;
 }
 
+table.table td,
 table.CALSTABLE td {
   background-color: #FFF;
 }
 
+table.table td,
+table.table th,
 table.CALSTABLE td,
 table.CALSTABLE th {
   border: 1px solid #A7C6DF;
@@ -440,6 +496,7 @@ a:hover {
   color:#666;
 }
 
+#docContainer code.function tt,
 #docContainer code.FUNCTION tt {
   font-size: 1em;
 }
-- 
2.10.2

